@@ -1,37 +1,27 @@
-(def tk-version "1.3.1")
-(def ks-version "1.3.0")
-(def jetty-version "9.2.10.v20150310")
+(def jetty-version "9.4.4.v20170414")
 
-(defproject puppetlabs/trapperkeeper-webserver-jetty9 "1.5.9"
+(defproject puppetlabs/trapperkeeper-webserver-jetty9 "2.1.0"
   :description "A jetty9-based webserver implementation for use with the puppetlabs/trapperkeeper service framework."
   :url "https://github.com/puppetlabs/trapperkeeper-webserver-jetty9"
   :license {:name "Apache License, Version 2.0"
             :url "http://www.apache.org/licenses/LICENSE-2.0"}
+
+  :min-lein-version "2.7.1"
+
+  :parent-project {:coords [puppetlabs/clj-parent "1.4.0"]
+                   :inherit [:managed-dependencies]}
+
   ;; Abort when version ranges or version conflicts are detected in
   ;; dependencies. Also supports :warn to simply emit warnings.
   ;; requires lein 2.2.0+.
   :pedantic? :abort
-  :dependencies [[org.clojure/clojure "1.7.0"]
+  :dependencies [[org.clojure/clojure]
+                 [org.clojure/java.jmx]
+                 [org.clojure/tools.logging]
 
-                 ;; begin version conflict resolution dependencies
-                 [clj-time "0.9.0"]
-                 [org.clojure/tools.reader "1.0.0-beta1"]
-                 ;; end version conflict resolution dependencies
-
-                 [org.clojure/java.jmx "0.3.1"]
-                 [org.clojure/tools.logging "0.2.6"]
-                 [prismatic/schema "1.0.4"]
-
-                 [puppetlabs/ssl-utils "0.8.1"]
-                 [puppetlabs/kitchensink ~ks-version]
-                 [puppetlabs/trapperkeeper ~tk-version]
-
-                 [ch.qos.logback/logback-access "1.1.3"]
-
-                 [org.codehaus.janino/janino "2.7.8"]
+                 [org.codehaus.janino/janino]
 
                  [javax.servlet/javax.servlet-api "3.1.0"]
-
                  ;; Jetty Webserver
                  [org.eclipse.jetty/jetty-server ~jetty-version
                   :exclusions [org.eclipse.jetty.orbit/javax.servlet]]
@@ -42,16 +32,22 @@
                  [org.eclipse.jetty/jetty-jmx ~jetty-version]
                  [org.eclipse.jetty.websocket/websocket-server ~jetty-version]
 
-                 [ring/ring-servlet "1.4.0"]
-                 [ring/ring-codec "1.0.0"]]
+                 [prismatic/schema]
+                 [ring/ring-servlet]
+                 [ring/ring-codec]
+
+                 [puppetlabs/ssl-utils]
+                 [puppetlabs/kitchensink]
+                 [puppetlabs/trapperkeeper]
+                 [puppetlabs/i18n]
+                 [puppetlabs/trapperkeeper-filesystem-watcher]
+                 ]
 
   :source-paths  ["src"]
   :java-source-paths  ["java"]
 
-  :plugins [[lein-release "1.0.5" :exclusions [org.clojure/clojure]]]
-
-  :lein-release {:scm         :git
-                 :deploy-via  :lein-deploy}
+  :plugins [[lein-parent "0.3.1"]
+            [puppetlabs/i18n "0.8.0"]]
 
   :deploy-repositories [["releases" {:url "https://clojars.org/repo"
                                      :username :env/clojars_jenkins_username
@@ -73,27 +69,20 @@
                                   "examples/webrouting_app/src"]
                    :java-source-paths ["examples/servlet_app/src/java"
                                        "test/java"]
-                   :dependencies [[puppetlabs/http-client "0.5.0"]
-                                  [puppetlabs/kitchensink ~ks-version :classifier "test"]
-                                  [puppetlabs/trapperkeeper ~tk-version :classifier "test"]
-                                  [org.clojure/tools.namespace "0.2.10"]
-                                  [spyscope "0.1.4"]
-                                  [compojure "1.1.8" :exclusions [ring/ring-core
-                                                                  commons-io
-                                                                  org.clojure/tools.macro]]
+                   :dependencies [[puppetlabs/http-client]
+                                  [puppetlabs/kitchensink nil :classifier "test"]
+                                  [puppetlabs/trapperkeeper nil :classifier "test"]
+                                  [org.clojure/tools.namespace]
+                                  [compojure]
                                   [stylefruits/gniazdo "0.4.0" :exclusions [org.eclipse.jetty.websocket/websocket-api
                                                                             org.eclipse.jetty.websocket/websocket-client
                                                                             org.eclipse.jetty/jetty-util]]
-                                  [ring/ring-core "1.4.0"]]
-                    :injections [(require 'spyscope.core)]
+                                  [ring/ring-core]]
                     ;; Enable SSLv3 for unit tests that exercise SSLv3
                     :jvm-opts ["-Djava.security.properties=./dev-resources/java.security"]}
 
              :testutils {:source-paths ^:replace ["test/clj"]
-                         :java-source-paths ^:replace ["test/java"]}
-             :uberjar {:aot [puppetlabs.trapperkeeper.main]
-                       :classifiers ^:replace []
-                       :dependencies [[org.clojure/tools.nrepl "0.2.6" :scope "test" :exclusions [[org.clojure/clojure]]]]}}
+                         :java-source-paths ^:replace ["test/java"]}}
 
   :main puppetlabs.trapperkeeper.main
   )
